################################################
Documenteer for LSST technical notes (technotes)
################################################

LSST technical notes (or *technotes*) are often written in reStructuredText, especially within LSST Data Management.
Documenteer provides centralized configuration and tooling for technotes.

.. toctree::
   :maxdepth: 2

   configuration
   refresh-lsst-bib

.. seealso::

   To learn more about technotes:

   - LSST DM Developer Guide: `Technotes for stand-alone technical documentation <https://developer.lsst.io/project-docs/technotes.html>`_
   - `SQR-000: The LSST DM Technical Note Publishing Platform <https://sqr-000.lsst.io>`_
